sipua
=====

|license| |version| |tests| |coverage| |docs|

.. |license| image:: https://img.shields.io/pypi/l/sipua.svg
   :target: https://pypi.python.org/pypi/sipua
   :alt: License

.. |version| image:: https://img.shields.io/pypi/v/sipua.svg
   :target: https://pypi.python.org/pypi/sipua
   :alt: Version

.. |tests| image:: https://github.com/spacinov/sipua/workflows/tests/badge.svg
   :target: https://github.com/spacinov/sipua/actions
   :alt: Tests

.. |coverage| image:: https://img.shields.io/codecov/c/github/spacinov/sipua.svg
   :target: https://codecov.io/gh/spacinov/sipua
   :alt: Coverage

.. |docs| image:: https://readthedocs.org/projects/sipua/badge/?version=latest
   :target: https://sipua.readthedocs.io/
   :alt: Documentation

The ``sipua`` project provides a library for writing SIP user agents in Python.
